@@ -1,15 +1,23 @@
 
+from typing import NewType
 from typing import TYPE_CHECKING
 from typing import cast
 
 from logging import Logger
 from logging import getLogger
 
+from enum import Enum
+
+from wx import Point
+from wx import VERTICAL
+from wx import HORIZONTAL
+from wx import SUNKEN_BORDER
+
 # I know it is there
 # noinspection PyUnresolvedReferences
 from wx.core import PenStyle
-from wx import SUNKEN_BORDER
 
+from wx import MouseEvent
 from wx import Bitmap
 from wx import Brush
 from wx import ClientDC
@@ -25,7 +33,7 @@ from wx import SystemSettings
 
 from wx import Window
 
-from wx.lib.ogl import ShapeCanvas
+from umlshapes.lib.ogl import ShapeCanvas
 
 from umlshapes.UmlUtils import UmlUtils
 from umlshapes.types.UmlColor import UmlColor
@@ -36,13 +44,28 @@ from umlshapes.preferences.UmlPreferences import UmlPreferences
 if TYPE_CHECKING:
     from umlshapes.UmlDiagram import UmlDiagram
 
+FrameId = NewType('FrameId', str)
+
+
+class WheelAxis(Enum):
+    WHEEL_AXIS_VERTICAL   = 0
+    WHEEL_AXIS_HORIZONTAL = 1
+
+    @classmethod
+    def toEnum(cls, value: int) -> 'WheelAxis':
+
+        if value == 0:
+            return WheelAxis.WHEEL_AXIS_VERTICAL
+        elif value == 1:
+            return WheelAxis.WHEEL_AXIS_HORIZONTAL
+        else:
+            assert False, f'Unknown wheel axis: {value=}'
+
 
 class DiagramFrame(ShapeCanvas):
     """
     A frame to draw UML diagrams.
-
     """
-
     def __init__(self, parent: Window):
         """
 
@@ -70,8 +93,9 @@ class DiagramFrame(ShapeCanvas):
         w, h = self.GetSize()
         self._workingBitmap: Bitmap = Bitmap(w, h)   # double buffering
 
-        self._isInfinite: bool = False    # Indicates if the frame is infinite
-        self._frameId:    str  = UmlUtils.getID()
+        self._isInfinite: bool    = False    # Indicates if the frame is infinite
+        # The ShapeCanvas ID is an integer;  use our own
+        self._id: FrameId = FrameId(UmlUtils.getID())
 
     @property
     def umlDiagram(self) -> 'UmlDiagram':
@@ -82,12 +106,13 @@ class DiagramFrame(ShapeCanvas):
         self.SetDiagram(newDiagram)
 
     @property
-    def frameId(self):
-        return self._frameId
+    def id(self) -> FrameId:
+        """
+        UmlFrame ID
 
-    @frameId.setter
-    def frameId(self, frameId: str):
-        self._frameId = frameId
+        Returns:  The UML generated Frame ID
+        """
+        return self._id
 
     def refresh(self, eraseBackground: bool = True):
 
@@ -165,6 +190,35 @@ class DiagramFrame(ShapeCanvas):
 
         dc.Blit(0, 0, w, h, mem, x, y)
 
+    def OnMouseEvent(self, mouseEvent: MouseEvent):
+        """
+        Add additional behaviour to add wheel mouse scrolling
+
+        Args:
+            mouseEvent:
+        """
+
+        rotation:  int       = mouseEvent.GetWheelRotation()
+        wheelAxis: WheelAxis = WheelAxis.toEnum(value=mouseEvent.GetWheelAxis())
+        inverted:  bool      = mouseEvent.IsWheelInverted()
+
+        if not inverted:
+            rotation = -rotation
+
+        self._dfLogger.debug(f'{wheelAxis} - {inverted=} - {rotation=}')
+
+        yScrollPosition: int = self.GetScrollPos(VERTICAL)
+        xScrollPosition: int = self.GetScrollPos(HORIZONTAL)
+
+        if wheelAxis == WheelAxis.WHEEL_AXIS_VERTICAL:
+            yScrollPosition += rotation
+        else:
+            xScrollPosition += rotation
+
+        self.Scroll(Point(x=xScrollPosition, y=yScrollPosition))
+
+        super().OnMouseEvent(evt=mouseEvent)
+
     def _drawGrid(self, memDC: DC, width: int, height: int, startX: int, startY: int):
 
         # self.clsLogger.info(f'{width=} {height=} {startX=} {startY=}')
