@@ -10,22 +10,21 @@ from wx import ClientDC
 from wx import MouseEvent
 from wx import Window
 
-from wx.lib.ogl import Shape
-from wx.lib.ogl import ShapeCanvas
+from umlshapes.lib.ogl import Shape
+from umlshapes.lib.ogl import ShapeCanvas
 
-from umlshapes.UmlUtils import UmlUtils
-from umlshapes.eventengine.IUmlEventEngine import IUmlEventEngine
+from umlshapes.pubsubengine.IUmlPubSubEngine import IUmlPubSubEngine
 
 from umlshapes.frames.DiagramFrame import DiagramFrame
 
 from umlshapes.UmlDiagram import UmlDiagram
 
 from umlshapes.preferences.UmlPreferences import UmlPreferences
+from umlshapes.pubsubengine.UmlMessageType import UmlMessageType
 
 from umlshapes.types.Common import UmlShapeList
+from umlshapes.types.UmlPosition import UmlPosition
 
-
-DEFAULT_WIDTH: int   = 3000
 A4_FACTOR:     float = 1.41
 
 PIXELS_PER_UNIT_X: int = 20
@@ -34,19 +33,19 @@ PIXELS_PER_UNIT_Y: int = 20
 
 class UmlFrame(DiagramFrame):
 
-    def __init__(self, parent: Window, umlEventEngine: IUmlEventEngine):
+    def __init__(self, parent: Window, umlPubSubEngine: IUmlPubSubEngine):
 
-        self.ufLogger:     Logger          = getLogger(__name__)
-        self._preferences: UmlPreferences  = UmlPreferences()
-        self._eventEngine: IUmlEventEngine = umlEventEngine
+        self.ufLogger:         Logger           = getLogger(__name__)
+        self._preferences:     UmlPreferences   = UmlPreferences()
+        self._umlPubSubEngine: IUmlPubSubEngine = umlPubSubEngine
 
         super().__init__(parent=parent)
 
-        self.maxWidth:  int  = DEFAULT_WIDTH
-        self.maxHeight: int = int(self.maxWidth / A4_FACTOR)  # 1.41 is for A4 support
+        self._maxWidth:  int  = self._preferences.virtualWindowWidth
+        self._maxHeight: int = int(self._maxWidth / A4_FACTOR)  # 1.41 is for A4 support
 
-        nbrUnitsX: int = int(self.maxWidth / PIXELS_PER_UNIT_X)
-        nbrUnitsY: int = int(self.maxHeight / PIXELS_PER_UNIT_Y)
+        nbrUnitsX: int = self._maxWidth // PIXELS_PER_UNIT_X
+        nbrUnitsY: int = self._maxHeight // PIXELS_PER_UNIT_Y
         initPosX:  int = 0
         initPosY:  int = 0
         self.SetScrollbars(PIXELS_PER_UNIT_X, PIXELS_PER_UNIT_Y, nbrUnitsX, nbrUnitsY, initPosX, initPosY, False)
@@ -54,11 +53,9 @@ class UmlFrame(DiagramFrame):
         self.setInfinite(True)
         self._currentReportInterval: int = self._preferences.trackMouseInterval
 
-        self._id: str = UmlUtils.getID()
-
     @property
-    def eventEngine(self) -> IUmlEventEngine:
-        return self._eventEngine
+    def umlPubSubEngine(self) -> IUmlPubSubEngine:
+        return self._umlPubSubEngine
 
     @property
     def umlShapes(self) -> UmlShapeList:
@@ -66,15 +63,6 @@ class UmlFrame(DiagramFrame):
         diagram: UmlDiagram = self.GetDiagram()
         return diagram.GetShapeList()
 
-    @property
-    def id(self) -> str:
-        """
-        UmlFrame ID
-
-        Returns:  The UML generated ID
-        """
-        return self._id
-
     def OnLeftClick(self, x, y, keys=0):
         """
         Maybe this belongs in DiagramFrame
@@ -95,6 +83,11 @@ class UmlFrame(DiagramFrame):
 
             umlShape.Select(select=False, dc=dc)
 
+        self._umlPubSubEngine.sendMessage(messageType=UmlMessageType.FRAME_LEFT_CLICK,
+                                          frameId=self.id,
+                                          frame=self,
+                                          umlPosition=UmlPosition(x=x, y=y)
+                                          )
         self.refresh()
 
     def OnMouseEvent(self, mouseEvent: MouseEvent):
