@@ -15,11 +15,12 @@ from wx import Font
 from wx import MemoryDC
 from wx import Size
 
-from wx.lib.ogl import Shape
+from umlshapes.lib.ogl import Shape
 
 from pyutmodelv2.PyutInterface import PyutInterface
 
 from umlshapes.UmlUtils import UmlUtils
+from umlshapes.mixins.IDMixin import IDMixin
 
 from umlshapes.preferences.UmlPreferences import UmlPreferences
 from umlshapes.mixins.TopLeftMixin import Rectangle
@@ -30,14 +31,14 @@ from umlshapes.types.UmlPosition import UmlPosition
 
 if TYPE_CHECKING:
     from umlshapes.shapes.UmlClass import UmlClass
-    from umlshapes.frames.UmlClassDiagramFrame import UmlClassDiagramFrame
+    from umlshapes.frames.ClassDiagramFrame import ClassDiagramFrame
 
 
-class UmlLollipopInterface(Shape):
+class UmlLollipopInterface(Shape, IDMixin):
     """
     Lollipops are tasty !!
     """
-    def __init__(self, pyutInterface: PyutInterface, canvas: Optional['UmlClassDiagramFrame'] = None):
+    def __init__(self, pyutInterface: PyutInterface, canvas: Optional['ClassDiagramFrame'] = None):
         """
 
         Args:
@@ -48,6 +49,8 @@ class UmlLollipopInterface(Shape):
         self._preferences:   UmlPreferences = UmlPreferences()
 
         super().__init__(canvas=canvas)
+        IDMixin.__init__(self, umlShape=self)
+
         self.logger: Logger = getLogger(__name__)
 
         self._lineCentum:       float = 0.1
@@ -57,6 +60,14 @@ class UmlLollipopInterface(Shape):
         self._attachedTo:       UmlClass       = cast('UmlClass', None)
         self._attachmentSide:   AttachmentSide = cast(AttachmentSide, None)
 
+    @property
+    def umlFrame(self) -> 'ClassDiagramFrame':
+        return self.GetCanvas()
+
+    @umlFrame.setter
+    def umlFrame(self, frame: 'ClassDiagramFrame'):
+        self.SetCanvas(frame)
+
     @property
     def pyutInterface(self) -> PyutInterface:
         return self._pyutInterface
