@@ -10,9 +10,9 @@ from pyutmodelv2.PyutInterface import PyutInterfaces
 
 from umlshapes.dialogs.DlgEditInterface import DlgEditInterface
 
-from umlshapes.eventengine.IUmlEventEngine import IUmlEventEngine
+from umlshapes.pubsubengine.IUmlPubSubEngine import IUmlPubSubEngine
 
-from umlshapes.frames.UmlClassDiagramFrame import UmlClassDiagramFrame
+from umlshapes.frames.ClassDiagramFrame import ClassDiagramFrame
 
 from umlshapes.links.UmlInterface import UmlInterface
 from umlshapes.links.UmlLollipopInterface import UmlLollipopInterface
@@ -36,14 +36,14 @@ class UmlLollipopInterfaceEventHandler(UmlBaseEventHandler):
         super().OnLeftDoubleClick(x=x, y=y, keys=keys, attachment=attachment)
 
         umlLollipopInterface: UmlLollipopInterface = self.GetShape()
-        umlFrame:             UmlClassDiagramFrame = umlLollipopInterface.GetCanvas()
+        umlFrame:             ClassDiagramFrame = umlLollipopInterface.GetCanvas()
 
         umlLollipopInterface.selected = False
         umlFrame.refresh()
 
         self.logger.info(f'{umlLollipopInterface=}')
 
-        eventEngine:    IUmlEventEngine = umlFrame.eventEngine
+        eventEngine:    IUmlPubSubEngine = umlFrame.umlPubSubEngine
         pyutInterfaces: PyutInterfaces = self.getDefinedInterfaces()
         with DlgEditInterface(parent=umlFrame, oglInterface2=umlLollipopInterface, eventEngine=eventEngine, pyutInterfaces=pyutInterfaces, editMode=True) as dlg:
             if dlg.ShowModal() == OK:
@@ -61,7 +61,7 @@ class UmlLollipopInterfaceEventHandler(UmlBaseEventHandler):
 
         """
         umlLollipopInterface: UmlLollipopInterface = self.GetShape()
-        umlFrame:             UmlClassDiagramFrame = umlLollipopInterface.GetCanvas()
+        umlFrame:             ClassDiagramFrame = umlLollipopInterface.GetCanvas()
 
         umlShapes:      UmlShapeList   = umlFrame.umlShapes
         pyutInterfaces: PyutInterfaces = PyutInterfaces([])
