@@ -8,7 +8,7 @@ from wx import OK
 
 from pyutmodelv2.PyutClass import PyutClass
 
-from umlshapes.frames.UmlClassDiagramFrame import UmlClassDiagramFrame
+from umlshapes.frames.ClassDiagramFrame import ClassDiagramFrame
 from umlshapes.preferences.UmlPreferences import UmlPreferences
 
 from umlshapes.shapes.UmlClass import UmlClass
@@ -23,7 +23,7 @@ class UmlClassEventHandler(UmlBaseEventHandler):
     """
 
     def __init__(self):
-        self.baseLogger:       Logger         = getLogger(__name__)
+        self.baseLogger:   Logger         = getLogger(__name__)
         self._preferences: UmlPreferences = UmlPreferences()
         super().__init__()
 
@@ -42,7 +42,7 @@ class UmlClassEventHandler(UmlBaseEventHandler):
             attachment:
         """
         umlClass: UmlClass              = self.GetShape()
-        umlFrame: UmlClassDiagramFrame  = umlClass.GetCanvas()
+        umlFrame: ClassDiagramFrame  = umlClass.GetCanvas()
         """
 
         I really don't like accessing the UML Frame is this manner because
@@ -64,25 +64,25 @@ class UmlClassEventHandler(UmlBaseEventHandler):
         super().OnRightClick(x=x, y=y, keys=keys, attachment=attachment)
 
         umlClass: UmlClass = self.GetShape()
-        umlFrame: UmlClassDiagramFrame  = umlClass.GetCanvas()
+        umlFrame: ClassDiagramFrame  = umlClass.GetCanvas()
 
         if self._menuHandler is None:
-            self._menuHandler = UmlClassMenuHandler(umlClass=umlClass, eventEngine=umlFrame.eventEngine)
+            self._menuHandler = UmlClassMenuHandler(umlClass=umlClass, umlPubSubEngine=umlFrame.umlPubSubEngine)
 
         self._menuHandler.popupMenu(x=x, y=y)
 
     def OnLeftDoubleClick(self, x: int, y: int, keys: int = 0, attachment: int = 0):
 
         from umlshapes.dialogs.umlclass.DlgEditClass import DlgEditClass
-        from umlshapes.eventengine.IUmlEventEngine import IUmlEventEngine
+        from umlshapes.pubsubengine.IUmlPubSubEngine import IUmlPubSubEngine
 
         super().OnLeftDoubleClick(x=x, y=y, keys=keys, attachment=attachment)
 
         umlClass:  UmlClass  = self.GetShape()
         pyutClass: PyutClass = umlClass.pyutClass
-        umlFrame:  UmlClassDiagramFrame  = umlClass.GetCanvas()
+        umlFrame:  ClassDiagramFrame  = umlClass.GetCanvas()
 
-        eventEngine: IUmlEventEngine = umlFrame.eventEngine
+        eventEngine: IUmlPubSubEngine = umlFrame.umlPubSubEngine
         with DlgEditClass(parent=umlFrame, pyutClass=pyutClass, eventEngine=eventEngine) as dlg:
             if dlg.ShowModal() == OK:
                 umlFrame.refresh()
