@@ -2,13 +2,14 @@
 from logging import Logger
 from logging import getLogger
 
+from wx import DC
 from wx import OK
 
 from pyutmodelv2.PyutNote import PyutNote
 
 from umlshapes.UmlBaseEventHandler import UmlBaseEventHandler
 from umlshapes.dialogs.DlgEditNote import DlgEditNote
-from umlshapes.frames.UmlClassDiagramFrame import UmlClassDiagramFrame
+from umlshapes.frames.UmlFrame import UmlFrame
 from umlshapes.shapes.UmlNote import UmlNote
 
 
@@ -27,10 +28,19 @@ class UmlNoteEventHandler(UmlBaseEventHandler):
         umlNote:  UmlNote  = self.GetShape()
         pyutNote: PyutNote = umlNote.pyutNote
 
-        umlFrame:  UmlClassDiagramFrame  = umlNote.GetCanvas()
+        umlFrame:  UmlFrame  = umlNote.GetCanvas()
 
         with DlgEditNote(parent=umlFrame, pyutNote=pyutNote,) as dlg:
             if dlg.ShowModal() == OK:
                 umlFrame.refresh()
 
         umlNote.selected = False
+
+    def OnMoveLink(self, dc: DC, moveControlPoints: bool = True):
+        """
+
+        Args:
+            dc:
+            moveControlPoints:
+        """
+        super().OnMoveLink(dc=dc, moveControlPoints=moveControlPoints)
